@@ -9,7 +9,7 @@ cd $AUTOPKGTEST_TMP
 
 for py3ver in $(py3versions -vs)
 do
-    for file in tests/*
+    for file in tests/test_*.py
     do
         echo "Running test ${file} with Python ${py3ver}."
         /usr/bin/python${py3ver} -B -m unittest ${file}
